@@ -229,17 +229,17 @@ def download():
         description="Download directories/folders from GitHub"
     )
 
-    parser.add_argument(
-        "country",
-        type=str,
-        default="Australia",
-        help="Name of the country for which the reference data to download",
-    )
+    # parser.add_argument(
+    #     "country",
+    #     type=str,
+    #     default="Australia",
+    #     help="Name of the country for which the reference data to download",
+    # )
 
-    args = parser.parse_args()
-    country = args.country
+    # args = parser.parse_args()
+    # country = args.country
 
-    download_data(country)
+    download_data()
     print_text("✔ Download complete", "green", in_place=True)
 
 
